@@ -6,24 +6,19 @@ import java.util.List;
 import java.util.stream.Collectors;
 import java.util.stream.IntStream;
 
-import org.springframework.beans.factory.annotation.Autowired;
-import org.springframework.stereotype.Component;
-
 import cz.jkuchar.rcba.rules.Item;
 import cz.jkuchar.rcba.rules.Rule;
 import cz.jkuchar.rcba.rules.RuleEngine;
 
-@Component
-public class DCBrCBA implements Pruning {
+public class DCBrCBA implements Pruning {	
+	
+	RuleEngine re = new RuleEngine();
 
-	@Autowired
-	RuleEngine re;
-
-	public List<Rule> prune(List<Rule> rules, List<Item> train) {
+	public List<Rule> prune(List<Rule> rules, List<Item> train) {		
 		Collections.sort(rules);
 		List<Rule> pruned = new LinkedList<Rule>();
 		for (Rule rule : rules) {
-			String className = rule.getCons().keySet().iterator().next();
+			String className = rule.getCons().keys().iterator().next();
 
 			List<Integer> matches = IntStream
 					.range(0, train.size())
